@@ -4,8 +4,7 @@
  *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef KSCREEN_DOCTOR_H
-#define KSCREEN_DOCTOR_H
+#pragma once
 
 #include <QCommandLineParser>
 #include <QObject>
@@ -46,6 +45,9 @@ public:
     void setRgbRange(OutputPtr output, KScreen::Output::RgbRange rgbRange);
     void setPrimary(OutputPtr output);
     void setPriority(OutputPtr output, uint32_t priority);
+    void setHdrEnabled(OutputPtr output, bool enable);
+    void setSdrBrightness(OutputPtr output, uint32_t brightness);
+    void setWcgEnabled(OutputPtr output, bool enable);
 
 Q_SIGNALS:
     void outputsChanged();
@@ -64,5 +66,3 @@ private:
 };
 
 } // namespace
-
-#endif // KSCREEN_WAYLAND_SCREEN_H
